@@ -16,8 +16,8 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#ifndef _CACHE_H
-#define _CACHE_H
+#ifndef CACHE_H
+#define CACHE_H
 
 int cache_init(void);
 int cache_store(char *key, const char *text);
