@@ -16,8 +16,8 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#ifndef _GAI_STRERROR_H
-#define _GAI_STRERROR_H
+#ifndef GAI_STRERROR_H
+#define GAI_STRERROR_H
 
 #include <config.h>
 
