@@ -16,8 +16,8 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#ifndef _JCONFIG_H
-#define _JCONFIG_H
+#ifndef JCONFIG_H
+#define JCONFIG_H
 
 struct jconfig {
 	char	*domain;
