@@ -17,8 +17,10 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef _UTILS_H
-#define _UTILS_H
+#ifndef UTILS_H
+#define UTILS_H
+
+#include "whois.h"
 
 char *get_whois_server_domain_path(const char *hostname);
 char *get_whois_server_option(const char *hostname, const char *key);
